.. Corpus Analytics Graph documentation master file, created by
   sphinx-quickstart on Thu Jul 28 13:08:52 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Corpus Analytics Graph's documentation!
==================================================
Corpus Analytics Graph (CAG) serves as a base framework for creating graphs, extending them, and analyzing them. You can read our :doc:`get started guide </reference/1_get_started>` to see some core concepts directly applied. If you want to read up on those concept, you should go to the :doc:`concept writeup </reference/0_concept>` 

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Reference
=========

.. toctree::
   :maxdepth: 2
   :glob:

   reference/*

Modules
=======

.. toctree::
   :maxdepth: 3
   :glob:

   modules/*